<?php
/*
 * Available Hooks:
 *
 * 1. dashboard_links: Links that appear on the dashboard.
 * 2. action_links: Links that appear in the action section of the application.
 * 3. topmenu_links: Links that are displayed in the top menu navigation.
 *
 * Notes:
 * - The `class_file` must match the name of the class it defines. For example,
 *   if your class is named `Pages`, the class file should be `Pages.php`.
 * - The module folder must also have the same name as the class. For instance,
 *   the folder structure should be `modules/Pages/Pages.php` (for the class).
 * - Ensure that the module's configuration and files are organized properly 
 *   to avoid autoloading issues.
 */

 return [
    'name' => 'Pages', 
    'class_file' => 'Pages.php', 
    'module_order' => 1, 

    'links' => [
        // Manage Pages Link
        [
            'title' => 'Manage Pages', 
            'class' => 'green', 
            'icon_class' => 'fas fa-file-lines', 
            'hook' => 'dashboard_links', 
            'access' => [1, 2], 
            'module' => 'Pages', 
            'file' => 'manage_pages.php', 
            'visible' => true, 
            'order' => 1, 
        ],
        // New Page Link
        [
            'title' => 'New Page',
            'class' => 'blue',
            'icon_class' => 'fas fa-plus-circle',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'Pages',
            'file' => 'add_page.php',
            'visible' => true,
            'order' => 2,
        ],
        // All Pages Link
        [
            'title' => 'All',
            'class' => 'green',
            'icon_class' => 'fas fa-list-alt',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'Pages',
            'file' => 'manage_pages.php',
            'visible' => true,
            'order' => 1,
        ],
        // Edit Page (Hidden)
        [
            'title' => 'Edit Page',
            'class' => 'hidden',
            'icon_class' => 'fas fa-edit',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'Pages',
            'file' => 'edit_page.php',
            'visible' => false,
            'order' => 3,
        ],
        // Manage Trash
        [
            'title' => 'Recycle Bin',
            'class' => '',
            'icon_class' => 'fas fa-trash',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'Pages',
            'file' => 'recycle_bin.php',
            'visible' => false,
            'order' => 3,
        ],
    ]
];