<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Create an instance of Pages
$pages = new Pages();

// Initialize variables for the page form
$formData = [
    'title' => $_POST['title'] ?? '',
    'text' => $_POST['text'] ?? '',
    'userId' => $_SESSION['user_id'] ?? '',
    'status' => $_POST['status'] ?? Pages::PAGE_STATUS_DRAFT // Default to draft if not set
];

// Handle the form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Attempt to create the page and capture the new post ID
    $newPostId = $pages->createPage($formData);

    if ($newPostId) {
        // If the page was created successfully, redirect to the edit page
        safeRedirect('module.php', ['module' => 'Pages', 'file' => 'edit_page.php', 'id' => $newPostId]);
    } else {
        // If creation failed, redirect back
        safeRedirect('module.php', ['module' => 'Pages', 'file' => 'add_page.php']);
    }
}

// Retrieve any messages to display
$messages = Message::get();
?>

<h1>Add Page</h1>

<!-- Display any messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Form for adding a new page -->
<form method="post" enctype="multipart/form-data" class="form">
    <div>
        <label for="title">Title:</label>
        <input type="text" name="title" id="title" required>
    </div>

    <div class="posts-form-grid gap-10">
        <div>
            <div>
                <label for="text">Text:</label>
                <textarea name="text" id="text" rows="25" class="tinymce"></textarea>
            </div>
        </div>

        <div>
            <div>
                <label for="status">Status:</label>
                <select name="status" id="status" required>
                    <option value="<?php echo Pages::PAGE_STATUS_PUBLISHED; ?>">Published</option>
                    <option value="<?php echo Pages::PAGE_STATUS_DRAFT; ?>">Draft</option>
                </select>
            </div>
        </div>
    </div>

    <div>
        <button type="submit"><i class="fas fa-plus"></i> Add Page</button>
    </div>

</form>