<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Create an instance of Pages
$pages = new Pages();

// Initialize variables
$id = $_GET['id'] ?? null;
$formData = [
    'title' => '',
    'text' => '',
    'status' => Pages::PAGE_STATUS_DRAFT // Default status
];

// Fetch the existing page if the ID is provided
if ($id !== null) {
    $page = $pages->getPageById($id);

    // Check if the user is authorized to edit this page
    if ($page && $pages->isAuthorizedUser($page['user_id'])) {
        $formData['title'] = sanitizeInput($page['title']);
        $formData['text'] = $page['text'];
        $formData['status'] = (int) $page['status']; // Fetch the existing status
    } else {
        // Redirect unauthorized users
        safeRedirect('module.php', ['module' => 'Pages', 'file' => 'manage_pages.php']);
        exit; // Stop further execution for unauthorized access
    }
}

// Handle the form submission to update the page
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $id !== null) {
    $formData['title'] = $_POST['title'] ?? '';
    $formData['text'] = $_POST['text'] ?? '';
    $formData['status'] = $_POST['status'] ?? Pages::PAGE_STATUS_DRAFT; // Capture status from the form

    // Update page
    if ($pages->editPage($id, $formData)) {
        safeRedirect('module.php', ['module' => 'Pages', 'file' => 'edit_page.php', 'id' => $id]);
    } else {
        safeRedirect('module.php', ['module' => 'Pages', 'file' => 'manage_pages.php']);
    }
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Edit Page</h1>

<!-- Display any messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Form for editing page -->
<form method="post" enctype="multipart/form-data" class="form">
    <div>
        <label for="title">Title:</label>
        <input type="text" name="title" id="title" required value="<?php echo sanitizeInput($formData['title']); ?>">
        <div style="margin-top: 5px;"><strong>Permalink:</strong> <a
                href="<?= generateBaseUrl(); ?>page.php?alias=<?= htmlspecialchars($page['alias']); ?>"
                target="_blank"><?= generateBaseUrl(); ?>page.php?alias=<?= htmlspecialchars($page['alias']); ?></a>
        </div>
    </div>

    <div class="posts-form-grid gap-10">
        <div>
            <div>
                <label for="text">Text:</label>
                <textarea name="text" rows="25" id="text"
                    class="tinymce"><?php echo sanitizeInput($formData['text']); ?></textarea>
            </div>
        </div>

        <div>
            <div>
                <label for="status">Status:</label>
                <select name="status" id="status" required>
                    <option value="<?php echo Pages::PAGE_STATUS_DRAFT; ?>" <?php echo ($formData['status'] === Pages::PAGE_STATUS_DRAFT) ? 'selected' : ''; ?>>Draft</option>
                    <option value="<?php echo Pages::PAGE_STATUS_PUBLISHED; ?>" <?php echo ($formData['status'] === Pages::PAGE_STATUS_PUBLISHED) ? 'selected' : ''; ?>>Published
                    </option>
                </select>
            </div>
        </div>
    </div>

    <div>
        <button type="submit"><i class="fas fa-save"></i> Update Page</button>
    </div>
</form>