<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) { die("Access denied."); }

// Create an instance of Pages
$pages = new Pages();

// Pages per page
$pagesPerPage = 10;

// Get total items for pagination
$pagination = new Pagination($pagesPerPage);

// Define the statuses you want to filter by (draft and published)
$statusesToFilter = [Pages::PAGE_STATUS_DRAFT, Pages::PAGE_STATUS_PUBLISHED];

// Get the total number of pages, filtered by the selected statuses
$total_items = count($pages->getAllPagesForCurrentUser($statusesToFilter));
$pagination->setTotalItems($total_items);

// Get current page, filtered by the selected statuses
$current_page = $pagination->getCurrentPage();
$pagesData = array_slice($pages->getAllPagesForCurrentUser($statusesToFilter), ($current_page - 1) * $pagination->getLimit(), $pagination->getLimit());

// Handle delete request
if (isset($_GET['delete_id'])) {
    $deleteId = $_GET['delete_id'];
    $pages->softDeletePage($deleteId);
    safeRedirect('module.php', ['module' => 'Pages', 'file' => 'manage_pages.php']);
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Manage Pages</h1>
<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?= sanitizeInput($msg['type']); ?>"><?= sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Table layout for Pages -->
<div class="div-table">
    <div class="div-table-header">
        <div class="header-item">Title</div>
        <div class="header-item">Author</div>
        <div class="header-item">Created At</div>
        <div class="header-item">Actions</div>
    </div>

    <div class="div-table-body">
        <?php if (empty($pagesData)): ?>
            <div class="div-table-item">
                <div class="item-content" colspan="4">No Pages found.</div>
            </div>
        <?php else: ?>
            <!-- Iterate through each page and display its information -->
            <?php foreach ($pagesData as $page): ?>
                <div class="div-table-item">
                    <div class="item-content"><a
                            href="<?= generateBaseUrl(); ?>page.php?alias=<?= htmlspecialchars($page['alias']); ?>"
                            target="_blank"><?= htmlspecialchars($page['title']); ?></a></div>
                    <div class="item-content"><?= htmlspecialchars(SimpleLogin::getUsernameById($page['user_id'])); ?></div>
                    <div class="item-content"><?= htmlspecialchars(formatDate($page['created_at'], 'Y/m/d')); ?></div>
                    <div class="item-content">
                        <!-- Link to edit the page -->
                        <a href="<?= ModuleLoader::generateUrl('Pages', 'edit_page.php', ['id' => $page['id']]); ?>"
                            class="action-icon edit-icon">
                            <span class="fas fa-edit"></span>
                        </a>
                        <!-- Link to delete the page -->
                        <a href="<?= ModuleLoader::generateUrl('Pages', 'manage_pages.php', ['delete_id' => $page['id']]); ?>"
                            class="action-icon delete-icon"
                            onclick="return confirm('Are you sure you want to delete this püage?');">
                            <span class="fas fa-trash-alt"></span>
                        </a>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
</div>

<!-- Render pagination links -->
<div class="pagination">
    <?= $pagination->render(ModuleLoader::generateUrl('Pages', 'manage_pages.php')); ?>
</div>