<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Initialize Settings class
$settings = new Settings();

// Retrieve the 'module_settings' parameter from the URL
$moduleSettings = isset($_GET['module_settings']) ? sanitizeInput($_GET['module_settings']) : null;

// Check if the form is submitted to save settings
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['saveSettings'])) {
    $module = $_POST['module'] ?? '';

    // Check if module is provided and settings are in the correct format
    if ($module && isset($_POST[$module]) && is_array($_POST[$module])) {
        // Handle the form data
        $settings->handleFormSubmission();

        // Redirect after saving
        safeRedirect('module.php', ['module' => 'Settings', 'file' => 'manage_settings.php', 'module_settings' => $moduleSettings]);
    }
}

// If a specific module is selected, show its settings form
if (!empty($moduleSettings)) {
    // Only show the form for the selected module
    $formHtml = $settings->generateSettingsForms($moduleSettings);
} else {
    // No module selected, show links to modules that have settings
    $formHtml = '';

    // Retrieve all settings to list available modules
    $allSettings = $settings->getAllSettings();

    // Display the modules with settings
    if (empty($allSettings)) {
        // If no settings are found, show a message indicating no modules have been accessed or installed
        $formHtml = '<p>No settings are available.</p>';
    } else {
        $formHtml .= '<div class="dashboard-links">';
        foreach ($allSettings as $module => $moduleSettings) {
            // Retrieve the module icon if it's set, otherwise use a default icon
            $moduleIcon = isset($moduleSettings['moduleIcon']) ? $moduleSettings['moduleIcon'] : 'fa-cogs'; // Default to 'fa-cogs'

            // Ensure the icon is a string before passing to htmlspecialchars
            if (is_array($moduleIcon)) {
                $moduleIcon = implode(' ', $moduleIcon); // Join array elements into a single string
            }

            // Generate a link for each module that has settings
            $formHtml .= '<a href="' . ModuleLoader::generateUrl('Settings', 'manage_settings.php', ['module_settings' => $module]) . '">';
            $formHtml .= '<i class="fas ' . htmlspecialchars($moduleIcon) . '"></i>' . ucfirst($module) . '</a>';
        }
        $formHtml .= '</div>';
    }
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Manage Settings</h1>

<!-- Display any messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<?php echo $formHtml; ?>