<?php
/*
 * Available Hooks:
 *
 * 1. dashboard_links: Links that appear on the dashboard.
 * 2. action_links: Links that appear in the action section of the application.
 * 3. topmenu_links: Links that are displayed in the top menu navigation.
 *
 * Notes:
 * - The `class_file` must match the name of the class it defines. For example,
 *   if your class is named `SimpleBlog`, the class file should be `SimpleBlog.php`.
 * - The module folder must also have the same name as the class. For instance,
 *   the folder structure should be `modules/SimpleBlog/SimpleBlog.php` (for the class).
 * - Ensure that the module's configuration and files are organized properly 
 *   to avoid autoloading issues.
 */

 return [
    'name' => 'Simple Blog', 
    'class_file' => 'SimpleBlog.php', 
    'module_order' => 1, 

    'links' => [
        // Manage Blog Link
        [
            'title' => 'Manage Blog', 
            'class' => 'green', 
            'icon_class' => 'fas fa-list-alt', 
            'hook' => 'dashboard_links', 
            'access' => [1, 2], 
            'module' => 'SimpleBlog', 
            'file' => 'manage_blog.php', 
            'visible' => true, 
            'order' => 1, 
        ],
        // New Post Link
        [
            'title' => 'New Post',
            'class' => '',
            'icon_class' => 'fas fa-plus-circle',
            'hook' => 'dashboard_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'add_blog_post.php',
            'visible' => true,
            'order' => 2,
        ],
        // Edit Templates Link
        [
            'title' => 'Edit Templates',
            'class' => '',
            'icon_class' => 'fas fa-paint-brush',
            'hook' => 'dashboard_links',
            'access' => [1],
            'module' => 'SimpleBlog',
            'file' => 'edit_templates.php',
            'visible' => true,
            'order' => 3,
        ],
        // Edit Templates Action
        [
            'title' => 'Edit Templates',
            'class' => '',
            'icon_class' => 'fas fa-paint-brush',
            'hook' => 'action_links',
            'access' => [1],
            'module' => 'SimpleBlog',
            'file' => 'edit_templates.php',
            'visible' => true,
            'order' => 4,
        ],
        // New Post Link
        [
            'title' => 'New Post',
            'class' => 'blue',
            'icon_class' => 'fas fa-plus-circle',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'add_blog_post.php',
            'visible' => true,
            'order' => 2,
        ],
        // All Blog Posts Link
        [
            'title' => 'All',
            'class' => 'green',
            'icon_class' => 'fas fa-list-alt',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'manage_blog.php',
            'visible' => true,
            'order' => 1,
        ],
        // Edit Entry Link (Hidden)
        [
            'title' => 'Edit Blog Entry',
            'class' => 'hidden',
            'icon_class' => 'fas fa-edit',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'edit_post.php',
            'visible' => false,
            'order' => 3,
        ],
        // Manage Comments Link (Hidden)
        [
            'title' => 'Manage Comments',
            'class' => 'hidden',
            'icon_class' => 'fas fa-comment',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'manage_comments.php',
            'visible' => false,
            'order' => 3,
        ],
        // Edit Comment Link (Hidden)
        [
            'title' => 'Edit Comment',
            'class' => 'hidden',
            'icon_class' => 'fas fa-edit',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'edit_comment.php',
            'visible' => false,
            'order' => 3,
        ],
        // Manage Trash
        [
            'title' => 'Recycle Bin',
            'class' => '',
            'icon_class' => 'fas fa-trash',
            'hook' => 'action_links',
            'access' => [1, 2],
            'module' => 'SimpleBlog',
            'file' => 'recycle_bin.php',
            'visible' => false,
            'order' => 3,
        ],
    ]
];