<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Create an instance of SimpleBlog and Smileys
$blog = new SimpleBlog();
$smileys = new Smileys();

// Retrieve all smileys using the getAllSmileys() function
$allSmileys = $smileys->getAllSmileys();

// Initialize variables for the blog form
$formData = [
    'title' => $_POST['title'] ?? '',
    'text' => $_POST['text'] ?? '',
    'hashtags' => $_POST['hashtags'] ?? '',
    'userId' => $_SESSION['user_id'] ?? '',
    'image' => $_FILES['image'] ?? null,
    'options' => ['is_image_required' => false],
    'status' => $_POST['status'] ?? SimpleBlog::POST_STATUS_DRAFT // Default to draft if not set
];

// Handle the form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Attempt to create the entry and capture the new post ID
    $newPostId = $blog->createEntry($formData);

    if ($newPostId) {
        // If the entry was created successfully, redirect to the edit page
        safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'edit_post.php', 'id' => $newPostId]);
    } else {
        // If creation failed, redirect back to the add blog post page
        safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'add_blog_post.php']);
    }
}

// Retrieve any messages to display
$messages = Message::get();
?>

<h1>Add New Blog Post</h1>

<!-- Display any messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Form for adding a new blog post -->
<form method="post" enctype="multipart/form-data" class="form">
    <div>
        <label for="title">Title:</label>
        <input type="text" name="title" id="title" required>
    </div>

    <div class="posts-form-grid gap-10">
        <div>
            <div>
                <label for="text">Entry Text:</label>
                <textarea name="text" rows="25" id="text" class="tinymce smiley-support"></textarea>
            </div>

            <br>

            <!-- Smileys Div -->
            <div class="smileys-list">
                <?php if (!empty($allSmileys)): ?>
                    <?php foreach ($allSmileys as $smiley): ?>
                        <div class="smiley-container" style="display: inline-block; margin-right: 10px;">
                            <img src="<?php echo normalizeUrl(generateBaseUrl() . basename(CONTENT_DIR) . Smileys::IMAGE_UPLOAD_DIR . ltrim($smiley['imageName'], '/')); ?>"
                                alt="<?php echo htmlspecialchars($smiley['metadata']['smileyCode']); ?>" class="smiley"
                                data-smiley="<?php echo htmlspecialchars($smiley['metadata']['smileyCode']); ?>" />
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
        </div>

        <div>
            <div>
                <label for="status">Status:</label>
                <select name="status" id="status" required>
                    <option value="<?php echo SimpleBlog::POST_STATUS_PUBLISHED; ?>">Published</option>
                    <option value="<?php echo SimpleBlog::POST_STATUS_DRAFT; ?>">Draft</option>
                </select>
            </div>
            <br>
            <div>
                <label for="hashtags">Hashtags:</label>
                <input type="text" name="hashtags" id="hashtags" placeholder="e.g. tag1, tag2, tag3">
            </div>
            <br>
            <div>
                <label for="image">Post Image:</label>
                <input type="file" name="image" id="image" accept="image/jpeg, image/webp, image/png, image/gif">

                <p style="font-size: 8pt; opacity: 0.5; padding-top: 10px;"><strong>Note:</strong> You can upload an
                    image of any size. The image can be styled with CSS to fit various formats, such as a wide article
                    banner or a smaller avatar. Customize its appearance as needed.</p>
            </div>
        </div>
    </div>

    <div>
        <button type="submit"><i class="fas fa-plus"></i> Add Post</button>
    </div>

</form>

<!-- JavaScript to Insert Smiley into TinyMCE -->
<?php if (ModuleLoader::getSetting('Default', 'tinyMCE')): ?>
    <script>
        // Wait for the TinyMCE editor to be initialized
        document.addEventListener('DOMContentLoaded', function () {
            // Make sure TinyMCE is initialized
            if (typeof tinymce !== 'undefined') {
                // Attach click event to smiley images
                document.querySelectorAll('.smiley').forEach(function (smiley) {
                    smiley.addEventListener('click', function () {
                        var smileyCode = smiley.getAttribute('data-smiley');

                        // Insert smiley into TinyMCE editor
                        tinymce.activeEditor.insertContent(' ' + smileyCode); // Add smiley code at cursor position
                    });
                });
            }
        });
    </script>
<?php else: ?>
    <script>
        // Wait for the DOM to be fully loaded
        document.addEventListener('DOMContentLoaded', function () {
            // Attach click event to each smiley image
            document.querySelectorAll('.smiley').forEach(function (smiley) {
                smiley.addEventListener('click', function () {
                    var smileyCode = smiley.getAttribute('data-smiley');

                    // Get all textareas with the "smiley-support" class
                    document.querySelectorAll('.smiley-support').forEach(function (textarea) {
                        // Get the current cursor position
                        var cursorPos = textarea.selectionStart;

                        // Get the text before and after the cursor
                        var textBefore = textarea.value.substring(0, cursorPos);
                        var textAfter = textarea.value.substring(cursorPos);

                        // Remove any extra spaces before or after the smiley
                        textBefore = textBefore.replace(/\s+$/, ''); // Remove trailing spaces before the smiley
                        textAfter = textAfter.replace(/^\s+/, ''); // Remove leading spaces after the smiley

                        // Insert the smiley code at the current cursor position, with a single space before it
                        textarea.value = textBefore + ' ' + smileyCode + ' ' + textAfter;

                        // Move the cursor to the right after the inserted smiley code
                        textarea.selectionStart = textarea.selectionEnd = cursorPos + smileyCode.length + 2; // +2 for space before and after the smiley
                    });
                });
            });
        });
    </script>
<?php endif; ?>