<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) { die("Access denied."); }

// Create an instance of SimpleBlog
$blog = new SimpleBlog();

// Check if an ID is provided for the comment
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die('Invalid comment ID');
}

$commentId = (int) $_GET['id'];
$comments = $blog->getComments();
$commentToEdit = null;

// Find the comment to edit
foreach ($comments as $comment) {
    if ($comment['id'] === $commentId) {
        $commentToEdit = $comment;
        break;
    }
}

// If the comment to edit is not found
if ($commentToEdit === null) {
    die('Comment not found');
}

// Handle the form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Capture form data
    $formData = [
        'name'    => $_POST['name'] ?? '',
        'email'   => $_POST['email'] ?? '',
        'website' => $_POST['website'] ?? '',
        'text'    => $_POST['text'] ?? '',
    ];

    // Sanitize the inputs
    $updatedComment = [
        'id' => $commentId,
        'post_id' => $commentToEdit['post_id'],
        'name' => sanitizeInput($formData['name']),
        'email' => sanitizeInput($formData['email']),
        'website' => sanitizeInput($formData['website']),
        'text' => sanitizeInput($formData['text']),
        'created_at' => $commentToEdit['created_at'], 
    ];

    // Use an update method to update the comment
    $blog->editComment($updatedComment);

    // Redirect after update
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'edit_comment.php', 'id' => $commentId]);
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Edit Comment</h1>
<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<form method="POST" class="form">
    <div>
        <label>Name:</label>
        <input type="text" name="name" value="<?php echo $commentToEdit['name']; ?>">
    </div>

    <div>
        <label>Email:</label>
        <input type="email" name="email" value="<?php echo $commentToEdit['email']; ?>">
    </div>

    <div>
        <label>Website:</label>
        <input type="url" name="website" value="<?php echo $commentToEdit['website']; ?>">
    </div>

    <div>
        <label>Comment:</label>
        <textarea name="text" required><?php echo $commentToEdit['text']; ?></textarea>
    </div>

    <div>
        <button type="submit"><i class="fas fa-save"></i> Update Comment</button>
    </div>
</form>
