<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Create an instance of SimpleBlog
$blog = new SimpleBlog();

$smileys = new Smileys();

// Retrieve all smileys using the getAllSmileys() function
$allSmileys = $smileys->getAllSmileys();

// Initialize variables
$id = $_GET['id'] ?? null;
$formData = [
    'title' => '',
    'text' => '',
    'hashtags' => '',
    'image' => $_FILES['image'] ?? null,
    'options' => ['is_image_required' => false],
    'status' => SimpleBlog::POST_STATUS_DRAFT // Default status
];

// Fetch the existing entry if the ID is provided
if ($id !== null) {
    $entry = $blog->getEntryById($id);

    // Check if the user is authorized to edit this entry
    if ($entry && $blog->isAuthorizedUser($entry['user_id'])) {
        // Populate form data if the user is authorized
        $formData['title'] = sanitizeInput($entry['title']);
        $formData['text'] = $entry['text'];
        $formData['hashtags'] = implode(', ', sanitizeInput($entry['hashtags']));
        $formData['image'] = sanitizeInput($entry['image']);
        $formData['status'] = (int) $entry['status']; // Fetch the existing status from the entry
    } else {
        // Redirect unauthorized users
        safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'manage_blog.php']);
        exit; // Stop further execution for unauthorized access
    }
}

// Handle the form submission to update the entry
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $id !== null) {
    $formData['title'] = $_POST['title'] ?? '';
    $formData['text'] = $_POST['text'] ?? '';
    $formData['hashtags'] = $_POST['hashtags'] ?? '';
    $formData['status'] = $_POST['status'] ?? SimpleBlog::POST_STATUS_DRAFT; // Capture status from the form

    // Capture the uploaded image
    $formData['image'] = $_FILES['image'] ?? null;

    // Update entry using the editEntry method
    if ($blog->editEntry($id, $formData)) {
        safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'edit_post.php', 'id' => $id]);
    } else {
        safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'manage_blog.php']);
    }
}

// Handle image deletion
if (isset($_GET['delete_post_image']) && $id !== null) {
    // Check if entry exists and contains an image
    if ($entry && !empty($entry['image'])) {
        // Call the clearPostImage method to delete the image and clear the entry reference
        if ($blog->clearPostImage($id)) {
            Message::set('success', 'Image deleted successfully.');
        } else {
            Message::set('error', 'Failed to delete the image.');
        }
    }

    // Redirect after deletion
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'edit_post.php', 'id' => $id]);
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Edit Blog Entry</h1>

<!-- Display any messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Form for editing blog entry -->
<form method="post" enctype="multipart/form-data" class="form">
    <div>
        <label for="title">Title:</label>
        <input type="text" name="title" id="title" required value="<?php echo sanitizeInput($formData['title']); ?>">
        <div style="margin-top: 5px;"><strong>Permalink:</strong> <a
                href="<?= generateBaseUrl(); ?>index.php?alias=<?= htmlspecialchars($entry['alias']); ?>"
                target="_blank"><?= generateBaseUrl(); ?>index.php?alias=<?= htmlspecialchars($entry['alias']); ?></a>
        </div>
    </div>

    <div class="posts-form-grid gap-10">
        <div>
            <div>
                <label for="text">Entry Text:</label>
                <textarea name="text" id="text" rows="25"
                    class="tinymce smiley-support"><?php echo sanitizeInput($formData['text']); ?></textarea>
            </div>

            <br>

            <!-- Smileys Div -->
            <div class="smileys-list">
                <?php if (!empty($allSmileys)): ?>
                    <?php foreach ($allSmileys as $smiley): ?>
                        <div class="smiley-container" style="display: inline-block; margin-right: 10px;">
                            <img src="<?php echo normalizeUrl(generateBaseUrl() . basename(CONTENT_DIR) . Smileys::IMAGE_UPLOAD_DIR . ltrim($smiley['imageName'], '/')); ?>"
                                alt="<?php echo htmlspecialchars($smiley['metadata']['smileyCode']); ?>" class="smiley"
                                data-smiley="<?php echo htmlspecialchars($smiley['metadata']['smileyCode']); ?>" />
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
        </div>

        <div>
            <div>
                <label for="status">Status:</label>
                <select name="status" id="status" required>
                    <option value="<?php echo SimpleBlog::POST_STATUS_DRAFT; ?>" <?php echo ($formData['status'] === SimpleBlog::POST_STATUS_DRAFT) ? 'selected' : ''; ?>>Draft</option>
                    <option value="<?php echo SimpleBlog::POST_STATUS_PUBLISHED; ?>" <?php echo ($formData['status'] === SimpleBlog::POST_STATUS_PUBLISHED) ? 'selected' : ''; ?>>Published
                    </option>
                </select>
            </div>

            <br>

            <div>
                <label for="hashtags">Hashtags:</label>
                <input type="text" name="hashtags" id="hashtags" placeholder="e.g. tag1, tag2, tag3"
                    value="<?php echo sanitizeInput($formData['hashtags']); ?>">
            </div>

            <br>

            <div>
                <label for="image">Post Image:</label>
                <?php if (!empty($formData['image'])): ?> <!-- Check if there is an existing image -->
                    <div class="form-image-container">
                        <a class="action-icon delete-icon"
                            href="<?= ModuleLoader::generateUrl('SimpleBlog', 'edit_post.php', ['id' => $id]); ?>&delete_post_image=1"
                            onclick="return confirm('Are you sure you want to delete this image?');">
                            <i class="fa-solid fa-circle-xmark"></i>
                        </a>

                        <img src="<?php echo $blog->getPostImage($formData['image']); ?>" alt="Current Image"
                            class="form-image">
                    </div>
                <?php else: ?>
                    <p>No image uploaded.</p>
                <?php endif; ?>
                <input type="file" name="image" id="image" accept="image/jpeg, image/webp, image/png, image/gif">
            </div>
        </div>
    </div>

    <div>
        <button type="submit"><i class="fas fa-save"></i> Update Post</button>
    </div>
</form>

<!-- JavaScript to Insert Smiley into TinyMCE -->
<?php if (ModuleLoader::getSetting('Default', 'tinyMCE')): ?>
    <script>
        // Wait for the TinyMCE editor to be initialized
        document.addEventListener('DOMContentLoaded', function () {
            // Make sure TinyMCE is initialized
            if (typeof tinymce !== 'undefined') {
                // Attach click event to smiley images
                document.querySelectorAll('.smiley').forEach(function (smiley) {
                    smiley.addEventListener('click', function () {
                        var smileyCode = smiley.getAttribute('data-smiley');

                        // Insert smiley into TinyMCE editor
                        tinymce.activeEditor.insertContent(' ' + smileyCode); // Add smiley code at cursor position
                    });
                });
            }
        });
    </script>
<?php else: ?>
    <script>
        // Wait for the DOM to be fully loaded
        document.addEventListener('DOMContentLoaded', function () {
            // Attach click event to each smiley image
            document.querySelectorAll('.smiley').forEach(function (smiley) {
                smiley.addEventListener('click', function () {
                    var smileyCode = smiley.getAttribute('data-smiley');

                    // Get all textareas with the "smiley-support" class
                    document.querySelectorAll('.smiley-support').forEach(function (textarea) {
                        // Get the current cursor position
                        var cursorPos = textarea.selectionStart;

                        // Get the text before and after the cursor
                        var textBefore = textarea.value.substring(0, cursorPos);
                        var textAfter = textarea.value.substring(cursorPos);

                        // Remove any extra spaces before or after the smiley
                        textBefore = textBefore.replace(/\s+$/, ''); // Remove trailing spaces before the smiley
                        textAfter = textAfter.replace(/^\s+/, ''); // Remove leading spaces after the smiley

                        // Insert the smiley code at the current cursor position, with a single space before it
                        textarea.value = textBefore + ' ' + smileyCode + ' ' + textAfter;

                        // Move the cursor to the right after the inserted smiley code
                        textarea.selectionStart = textarea.selectionEnd = cursorPos + smileyCode.length + 2; // +2 for space before and after the smiley
                    });
                });
            });
        });
    </script>
<?php endif; ?>