<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) { die("Access denied."); }

// Create an instance of SimpleBlog
$blog = new SimpleBlog();

// Comments per page
$commentsPerPage = 10;

// Check if an entry ID is provided
if (!isset($_GET['entry_id']) || !is_numeric($_GET['entry_id'])) {
    die('Invalid entry ID');
}

$postId = (int)$_GET['entry_id'];

// Retrieve the entry details to get the user ID of the post owner
$entry = $blog->getEntryById($postId);
if (!$entry) {
    die('Entry not found');
}

// Check if the current user is authorized to access this page
if (!$blog->isAuthorizedUser($entry['user_id'])){
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'manage_blog.php']);
}

// Get total items for pagination
$pagination = new Pagination($commentsPerPage);
$total_items = count($blog->getCommentsByPostId($postId)); // Get total comments for the specific entry
$pagination->setTotalItems($total_items);

// Get current page comments
$current_page = $pagination->getCurrentPage();
$comments = array_slice($blog->getCommentsByPostId($postId), ($current_page - 1) * $pagination->getLimit(), $pagination->getLimit());

// Handle delete request for comments
if (isset($_GET['delete_id'])) {
    $deleteId = (int)$_GET['delete_id']; // Ensure this is treated as an integer
    $blog->deleteComment($deleteId);
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'manage_comments.php', 'entry_id' => $postId]);
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Manage Comments for "<?php echo htmlspecialchars($entry['title']); ?>"</h1>
<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Table layout for comments -->
<div class="div-table">
    <div class="div-table-header">
        <div class="header-item">Name</div>
        <div class="header-item">Email</div>
        <div class="header-item">Website</div>
        <div class="header-item">Actions</div>
    </div>

    <div class="div-table-body">
        <?php if (empty($comments)): ?>
            <div class="div-table-item">
                <div class="item-content" colspan="5">No comments found for this entry.</div>
            </div>
        <?php else: ?>
            <!-- Iterate through each comment and display its information -->
            <?php foreach ($comments as $comment): ?>
                <div class="div-table-item">
                    <div class="item-content"><?php echo htmlspecialchars($comment['name']); ?></div>
                    <div class="item-content"><?php echo htmlspecialchars($comment['email']); ?></div>
                    <div class="item-content"><?php echo htmlspecialchars($comment['website']); ?></div>
                    <div class="item-content">
                        <!-- Check if user can edit this comment -->
                        <?php if ($blog->isAuthorizedUser($_SESSION['user_id']) || $comment['user_id'] === $_SESSION['user_id']): ?>
                            <a href="<?php echo ModuleLoader::generateUrl('SimpleBlog', 'edit_comment.php', ['id' => $comment['id']]); ?>" class="action-icon edit-icon">
                                <span class="fas fa-edit"></span>
                            </a>
                        <?php endif; ?>
                        <a href="<?php echo ModuleLoader::generateUrl('SimpleBlog', 'manage_comments.php', ['entry_id' => $postId, 'delete_id' => $comment['id']]); ?>" class="action-icon delete-icon"
                            onclick="return confirm('Are you sure you want to delete this comment?');">
                            <span class="fas fa-trash-alt"></span>
                        </a>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
</div>

<!-- Render pagination links -->
<div class="pagination">
    <?php echo $pagination->render(ModuleLoader::generateUrl('SimpleBlog', 'manage_comments.php', ['entry_id' => $postId])); ?>
</div>
