<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) { die("Access denied."); }

// Create an instance of SimpleBlog
$blog = new SimpleBlog();

// Entries per page
$entriesPerPage = 10;

// Get total items for pagination
$pagination = new Pagination($entriesPerPage);
$total_items = count($blog->getAllEntriesForCurrentUser(SimpleBlog::POST_STATUS_DELETED)); // Get the total number of entries
$pagination->setTotalItems($total_items);

// Get current page entries
$current_page = $pagination->getCurrentPage();
$entries = array_slice($blog->getAllEntriesForCurrentUser(SimpleBlog::POST_STATUS_DELETED), ($current_page - 1) * $pagination->getLimit(), $pagination->getLimit());

// Handle delete request
if (isset($_GET['delete_id'])) {
    $deleteId = $_GET['delete_id'];
    $blog->deleteEntry($deleteId);
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'recycle_bin.php']);
}

// Handle restore request
if (isset($_GET['restore_id'])) {
    $restoreId = $_GET['restore_id'];
    $blog->restoreEntry($restoreId);
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'manage_blog.php']);
}

// Handle clear recycle bin request
if (isset($_GET['clear_recycle_bin']) && $_GET['clear_recycle_bin'] === 'true') {
    $blog->clearRecycleBin();
    safeRedirect('module.php', ['module' => 'SimpleBlog', 'file' => 'recycle_bin.php']);
}

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1>Recycle Bin</h1>
<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?= sanitizeInput($msg['type']); ?>"><?= sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Link to clear the recycle bin -->
<div class="flex gap-10">
    <a href="<?= ModuleLoader::generateUrl('SimpleBlog', 'recycle_bin.php', ['clear_recycle_bin' => 'true']); ?>"
       class="button" 
       onclick="return confirm('Are you sure you want to permanently delete all soft-deleted entries?');">
        Clear All
    </a>
</div>

<!-- Table layout for blog entries -->
<div class="div-table">
    <div class="div-table-header">
        <div class="header-item">Title</div>
        <div class="header-item">Author</div>
        <div class="header-item">Created At</div>
        <div class="header-item">Actions</div>
    </div>

    <div class="div-table-body">
        <?php if (empty($entries)): ?>
            <div class="div-table-item">
                <div class="item-content" colspan="4">No blog entries found.</div>
            </div>
        <?php else: ?>
            <!-- Iterate through each blog entry and display its information -->
            <?php foreach ($entries as $entry): ?>
                <div class="div-table-item">
                    <div class="item-content"><a
                            href="<?= generateBaseUrl(); ?>index.php?alias=<?= htmlspecialchars($entry['alias']); ?>"
                            target="_blank"><?= htmlspecialchars($entry['title']); ?></a></div>
                    <div class="item-content"><?= htmlspecialchars(SimpleLogin::getUsernameById($entry['user_id'])); ?></div>
                    <div class="item-content"><?= htmlspecialchars(formatDate($entry['created_at'], 'Y/m/d')); ?></div>
                    <div class="item-content">
                        <!-- Link to restore the entry -->
                        <a href="<?= ModuleLoader::generateUrl('SimpleBlog', 'recycle_bin.php', ['restore_id' => $entry['id']]); ?>"
                            class="action-icon edit-icon">
                            <span class="fas fa-undo-alt"></span>
                        </a>
                        <!-- Link to delete the entry -->
                        <a href="<?= ModuleLoader::generateUrl('SimpleBlog', 'recycle_bin.php', ['delete_id' => $entry['id']]); ?>"
                            class="action-icon delete-icon"
                            onclick="return confirm('Are you sure you want to delete this entry?');">
                            <span class="fas fa-trash-alt"></span>
                        </a>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
</div>

<!-- Render pagination links -->
<div class="pagination">
    <?= $pagination->render(ModuleLoader::generateUrl('SimpleBlog', 'manage_blog.php')); ?>
</div>