<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Instantiate the Smileys class
$smileys = new Smileys();

// Handle file upload
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['smileyImage'])) {
    $uploadMessage = $smileys->createSmiley($_POST);
}

// Handle smiley update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['imageName'])) {
    // Update the smiley based on the imageName
    $updateResponse = $smileys->updateSmiley($_POST['imageName'], $_POST['smileyCode']);
    safeRedirect('module.php', ['module' => 'Smileys', 'file' => 'manage_smileys.php']);
}

// Handle file deletion
if (!empty($_GET['delete'])) {
    $deleteResponse = $smileys->deleteSmiley($_GET['delete']);
    safeRedirect('module.php', ['module' => 'Smileys', 'file' => 'manage_smileys.php']);
}

// Retrieve all uploaded smileys
$allSmileys = $smileys->getAllSmileys();
$messages = Message::get();

// Load smiley data if editing
$editSmiley = null;
if (!empty($_GET['edit'])) {
    foreach ($allSmileys as $smiley) {
        if ($smiley['imageName'] === $_GET['edit']) {
            $editSmiley = $smiley;
            break;
        }
    }
}
?>

<h1>Create Smileys</h1>

<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<!-- Smiley Form (Upload/Edit) -->
<form method="post" enctype="multipart/form-data" class="form size-small centered">
    <!-- Conditionally remove "horizontal" class when editing -->
    <div class="<?php echo $editSmiley ? '' : 'horizontal'; ?>">
        <?php if (!$editSmiley): ?>
            <div>
                <label for="smileyImage">Smiley Image</label>
                <input type="file" name="smileyImage" id="smileyImage" required>
            </div>
        <?php endif; ?>

        <div>
            <label for="smileyCode">Smiley Code:</label>
            <input type="text" name="smileyCode" id="smileyCode" placeholder="e.g. :happy:" required
                value="<?php echo $editSmiley['metadata']['smileyCode'] ?? ''; ?>">
        </div>
    </div>

    <div>
        <?php if ($editSmiley): ?>
            <div class="horizontal">
                <input type="hidden" name="imageName" value="<?php echo htmlspecialchars($editSmiley['imageName']); ?>">
                <button type="submit" class="large">Update</button>

                <a href="module.php?module=Smileys&file=manage_smileys.php" class="button large">Cancel</a>
            </div>
        <?php else: ?>
            <button type="submit" class="large">Add</button>
        <?php endif; ?>
    </div>
</form>

<br>

<h1>Current Smileys</h1>
<?php if (!empty($allSmileys)): ?>
    <div id="smileys-overview">
        <?php foreach ($allSmileys as $smileyMetadata): ?>
            <div class="smiley-container">
                <img src="<?php echo normalizeUrl(generateBaseUrl() . basename(CONTENT_DIR) . Smileys::IMAGE_UPLOAD_DIR . ltrim($smileyMetadata['imageName'], '/')); ?>"
                    alt="<?php echo $smileyMetadata['imageName']; ?>" style="max-width:100px; max-height: 100px;">

                <code><?php echo $smileyMetadata['metadata']['smileyCode']; ?></code>

                <!-- Delete Icon with confirmation -->
                <a href="<?= ModuleLoader::generateUrl('Smileys', 'manage_smileys.php') . '&delete=' . urlencode($smileyMetadata['imageName']); ?>"
                    onclick="return confirm('Are you sure you want to delete this smiley?');" title="Delete Smiley"
                    class="action-icon delete-icon">
                    <i class="fas fa-trash-alt"></i>
                </a>

                <!-- Edit Icon -->
                <a href="<?= ModuleLoader::generateUrl('Smileys', 'manage_smileys.php') . '&edit=' . urlencode($smileyMetadata['imageName']); ?>"
                    title="Edit Smiley" class="action-icon edit-icon">
                    <i class="fas fa-edit"></i>
                </a>
            </div>
        <?php endforeach; ?>
    </div>

<?php else: ?>
    <p>No smileys uploaded yet.</p>
<?php endif; ?>