<?php
// Protects the module files from being accessed directly
if (!defined('ALLOW_DIRECT_ACCESS')) {
    die("Access denied.");
}

// Instantiate the Updater class
$updater = new Updater();

// Check if the user has submitted manual JSON data
$manualJsonData = null;
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['jsonData'])) {
    // Fix the JSON input
    $fixedJsonData = $updater->fixJsonInput($_POST['jsonData']);
    
    // Attempt to decode the fixed JSON
    $manualJsonData = json_decode($fixedJsonData, true);

    // Check if the JSON was decoded successfully
    if (json_last_error() === JSON_ERROR_NONE) {
        // Proceed with the update check
        $updateData = $updater->checkForUpdatesInModules(MODULES_DIR, $manualJsonData);
        
        // Get available updates
        $updatesAvailable = $updateData['updatesAvailable'];
        $upToDate = $updateData['upToDate'];
    } else {
        Message::set('error', 'The provided JSON data is malformed. Please check your input.');
    }
}

// Get the update data
$updateData = $updater->checkForUpdatesInModules(MODULES_DIR, $manualJsonData);

// Check if updates are available
$updatesAvailable = $updateData['updatesAvailable'];
$upToDate = $updateData['upToDate'];

// Determine which message to show for "Up to date"
$allModulesUpToDate = empty($updatesAvailable) && !empty($upToDate);

// Retrieve any messages to display to the user
$messages = Message::get();
?>

<h1><span class="fas fa-cloud-download-alt"></span> Updates Available</h1>

<!-- Display messages -->
<?php if (!empty($messages)): ?>
    <?php foreach ($messages as $msg): ?>
        <p class="<?= sanitizeInput($msg['type']); ?>"><?= sanitizeInput($msg['text']); ?></p>
    <?php endforeach; ?>
<?php endif; ?>

<?php if (ini_get('allow_url_fopen')): ?>
    <!-- Display updates table for hosts supporting furl -->
    <div class="div-table">
        <div class="div-table-header">
            <div class="header-item">Module</div>
            <div class="header-item">Current Version</div>
            <div class="header-item">Update Version</div>
            <div class="header-item">Action</div>
        </div>

        <div class="div-table-body">
            <?php if (empty($updatesAvailable)): ?>
                <div class="div-table-item">
                    <div class="item-content" colspan="4">No updates available.</div>
                </div>
            <?php else: ?>
                <?php foreach ($updatesAvailable as $update): ?>
                    <div class="div-table-item">
                        <div class="item-content"><?= htmlspecialchars($update['title']); ?></div>
                        <div class="item-content"><?= htmlspecialchars($update['currentVersion']); ?></div>
                        <div class="item-content"><?= htmlspecialchars($update['updateVersion']); ?></div>
                        <div class="item-content">
                            <a href="<?= htmlspecialchars($update['downloadLink']); ?>" target="_blank"
                               class="action-icon edit-icon">
                               <span class="fas fa-download"></span>
                            </a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <br>

    <!-- "Up to date" section for hosts supporting furl -->
    <h1><span class="fas fa-check-circle"></span> Up to date</h1>
    <div class="div-table">
        <div class="div-table-header">
            <div class="header-item">Module</div>
            <div class="header-item">Current Version</div>
        </div>

        <div class="div-table-body">
            <?php if (empty($upToDate)): ?>
                <div class="div-table-item">
                    <div class="item-content" colspan="3">No modules are up-to-date.</div>
                </div>
            <?php else: ?>
                <?php foreach ($upToDate as $module): ?>
                    <div class="div-table-item">
                        <div class="item-content"><?= htmlspecialchars($module['title']); ?></div>
                        <div class="item-content"><?= htmlspecialchars($module['currentVersion']); ?></div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

<?php else: ?>
    <p>Unfortunately, your hosting provider has disabled the <strong>allow_url_fopen</strong> PHP function, which prevents
        the updater from retrieving the latest update information. As a result, the updater cannot work on your
        web host. However, you can manually provide the update JSON data.</p>
    <br>
    <p>Go to <a href="https://designfreaks.net/simplify_updater/latest.json"
            target="_blank">https://designfreaks.net/simplify_updater/latest.json</a>, copy the JSON content, and paste it
        below:</p>

    <br>

    <form method="POST" class="form">
        <textarea name="jsonData" rows="10" cols="100" placeholder="Paste the JSON data here..."></textarea>
        <button type="submit">Check for updates</button>
    </form>

    <?php if ($manualJsonData): ?>
        <br>

        <div class="success">Manual JSON data successfully processed. Checking for updates...</div>

        <div class="div-table">
            <div class="div-table-header">
                <div class="header-item">Module</div>
                <div class="header-item">Current Version</div>
                <div class="header-item">Update Version</div>
                <div class="header-item">Action</div>
            </div>

            <div class="div-table-body">
                <?php if (empty($updatesAvailable)): ?>
                    <div class="div-table-item">
                        <div class="item-content" colspan="4">No updates available.</div>
                    </div>
                <?php else: ?>
                    <?php foreach ($updatesAvailable as $update): ?>
                        <div class="div-table-item">
                            <div class="item-content"><?= htmlspecialchars($update['title']); ?></div>
                            <div class="item-content"><?= htmlspecialchars($update['currentVersion']); ?></div>
                            <div class="item-content"><?= htmlspecialchars($update['updateVersion']); ?></div>
                            <div class="item-content">
                                <a href="<?= htmlspecialchars($update['downloadLink']); ?>" target="_blank"
                                    class="action-icon edit-icon">
                                    <span class="fas fa-download"></span>
                                </a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
        </div>
    <?php endif; ?>
<?php endif; ?>
