<?php
/**
 * Configuration File for the Project
 *
 * Contains environment settings, directory definitions, and error handling configurations.
 */

// Name of the script folder
define('SCRIPT_FOLDER', 'simplify');

// Essential directories
define('USER_DATA_DIR', __DIR__ . '/user_data');
define('CLASSES_DIR', __DIR__ . '/class');
define('CONTENT_DIR', dirname(__DIR__) . '/content');
define('MODULES_DIR', dirname(__DIR__) . '/modules');

// Is the registration open?
define('REGISTRATION_OPEN', ModuleLoader::getSetting('Default', 'registrationStatus'));

// Generate the base URL or use CUSTOM_BASE_URL if defined
$defaultBaseUrl = getFullBaseUrl();
define('BASE_URL', defined('CUSTOM_BASE_URL') ? CUSTOM_BASE_URL : $defaultBaseUrl);

// Ensure that required directories exist
ensureRequiredDirectories([
    USER_DATA_DIR,
    CLASSES_DIR,
    CONTENT_DIR,
    MODULES_DIR,
]);

// Set error reporting
if (ModuleLoader::getSetting('Default', 'showErrors')) {
    error_reporting(E_ALL);
    ini_set('display_errors', 1);
} else {
    error_reporting(0);
    ini_set('display_errors', 0);
}

// Protects core files from being accessed directly when they're not included
// Never change this value!
define('ALLOW_DIRECT_ACCESS', true);