<?php
// Load necessary classes and functions
require_once __DIR__ . '/autoload.php';
require_once __DIR__ . '/functions.php';
require_once __DIR__ . '/config.php';

// Initialize the login class
$auth = new SimpleLogin();

// Ensure user is logged in
$auth->requireLogin();

// Load modules and register hooks
$modules = ModuleLoader::loadModules();

// Retrieve and display links for the dashboard
$dashboardLinks = HookManager::executeHook('dashboard_links');

// Retrieve any error or success messages
$messages = Message::get();

// Include header file for the page layout
include_once __DIR__ . '/header.php';
?>

<div class="content">
    <h1>Dashboard</h1>

    <!-- Display any messages -->
    <?php if (!empty($messages)): ?>
        <?php foreach ($messages as $msg): ?>
            <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
        <?php endforeach; ?>
    <?php endif; ?>

    <!-- Welcome message for the logged-in user -->
    <p style="text-align: center;">Welcome, <?php echo sanitizeInput($_SESSION['username']); ?>!</p>

    <nav class="dashboard-links">
        <?php if (!empty($dashboardLinks) && is_array($dashboardLinks)): ?>
            <?php echo implode("\n", $dashboardLinks); ?>
        <?php endif; ?>
    </nav>
</div>

<!-- Include footer file for the page layout -->
<?php include_once __DIR__ . '/footer.php'; ?>
