<!DOCTYPE html>
<html>

<head>
	<title>Simplify</title>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">

	<!-- Favicon -->
	<link rel="shortcut icon" type="image/x-icon" href="">

	<!-- Stylesheets -->
	<link rel="stylesheet" type="text/css" href="css/forms.css">
	<link rel="stylesheet" type="text/css" href="css/style.css?<?= time(); ?>">
	<?php if (ModuleLoader::getSetting('Default', 'darkMode')): ?>
		<link rel="stylesheet" type="text/css" href="css/style-dark.css?<?= time(); ?>">
	<?php endif; ?>

	<?php
	// Check if the accentColor differs from the default color
	$defaultAccentColor = '#7480e9'; // Define the default color here
	
	// Get the accent color from the settings
	$accentColor = ModuleLoader::getSetting('Default', 'simplifyAccentColor') ?: $defaultAccentColor;
	?>

	<!-- Custom accent color if it's different from the default -->
	<?php if ($defaultAccentColor !== $accentColor): ?>
		<style>
			:root {
				--accent-color:
					<?= htmlspecialchars($accentColor); ?>
				;

				/* Override with generic color only if simplifyAccentColor is different from the default */
				--view-color: var(--generic-color);
				--edit-color: var(--generic-color);
				--delete-color: var(--generic-color);
				--manage-color: var(--generic-color);
			}
		</style>
	<?php endif; ?>

	<script src='<?= getFullBaseUrl(); ?>js/tinymce/tinymce.min.js'></script>

	<?php if (ModuleLoader::getSetting('Default', 'tinyMCE')): ?>
		<script>
			// Check dark mode setting from your server-side code
			var isDarkMode = <?php echo json_encode(ModuleLoader::getSetting('Default', 'darkMode')); ?>;

			// Define skin and content_css based on dark mode setting
			var skin = isDarkMode ? 'oxide-dark' : 'oxide';
			var contentCss = isDarkMode ? 'dark' : '';

			// Initialize TinyMCE with the selected skin and content_css
			tinymce.init({
				selector: '.tinymce',
				promotion: false,
				branding: false,
				relative_urls: false,
				remove_script_host: false,
				extended_valid_elements: '*[*]',
				entity_encoding: 'raw',
				skin: skin, // Set the skin dynamically
				content_css: contentCss, // Set the content CSS dynamically
				plugins: [
					"advlist",
					"anchor",
					"autolink",
					"code",
					"codesample",
					"fullscreen",
					"image",
					"link",
					"lists",
					"media",
					"preview",
					"searchreplace",
					"table",
				],
				toolbar: "undo redo | styles | bold italic underline strikethrough | alignleft aligncenter alignright alignjustify | bullist numlist link image code",
			});
		</script>
	<?php endif; ?>
</head>

<body>

	<div id="container">
		<?php if ($auth->isLoggedIn()): ?>
			<div id="topbar">
				<nav class="topmenu">
					<div class="logo">
						<a href="<?= getFullBaseUrl(); ?>"><span class="fa-solid fa-wand-magic-sparkles"></span>
							Simplify</a>
					</div>

					<div class="flex gap-5">
						<?php
						// Collect and render top menu links
						$topMenuLinks = HookManager::executeHook('topmenu_links');

						// Output each link
						foreach ($topMenuLinks as $linkHtml) {
							echo $linkHtml; // Render the collected HTML
						}

						// Existing links
						echo '<a href="edit_profile.php"><span class="fa fa-user"></span> Edit Profile</a>';
						echo '<a href="logout.php"><span class="fa fa-sign-out"></span> Logout</a>';
						?>
					</div>
				</nav>
			</div>
		<?php endif; ?>