<?php
// Load necessary classes and functions
require_once __DIR__ . '/autoload.php';
require_once __DIR__ . '/functions.php';
require_once __DIR__ . '/config.php';

// Initialize the login class
$auth = new SimpleLogin();

// Process login if form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = trim($_POST['email']);
    $password = trim($_POST['password']);

    // Attempt to log in the user
    if ($auth->login($email, $password)) {
        // Redirect to the dashboard after successful login
        safeRedirect("dashboard.php");
    }
}

// Retrieve any error or success messages
$messages = Message::get();

// Include header file for the page layout
include_once __DIR__ . '/header.php';
?>

<div class="flex-container centered">
    <h1>Login</h1>

    <!-- Display any messages -->
    <?php if (!empty($messages)): ?>
        <?php foreach ($messages as $msg): ?>
            <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
        <?php endforeach; ?>
    <?php endif; ?>

    <!-- Login form -->
    <form action="login.php" method="post" class="form login-form">
        <div class="horizontal">
            <div>
                <label for="email">Email:</label>
                <input type="email" name="email" placeholder="" id="email" required>
            </div>

            <div>
                <label for="password">Password:</label>
                <input type="password" name="password" id="password" required>
            </div>
        </div>

        <button type="submit" class="large">Login</button>
    </form>

    <!-- Registration link if open -->
    <?php if ($auth->isRegistrationOpen()): ?>
        <p>Don't have an account? <a href="register.php">Register here</a>.</p>
    <?php endif; ?>
</div>

<!-- Include footer file for the page layout -->
<?php include_once __DIR__ . '/footer.php'; ?>