<?php
// Load necessary classes and functions
require_once __DIR__ . '/autoload.php';
require_once __DIR__ . '/functions.php';
require_once __DIR__ . '/config.php';

// Initialize the login class
$auth = new SimpleLogin();

// Ensure user is logged in
$auth->requireLogin();

// Allow access only for admin users
$auth->requireAdmin();

// Load modules and register hooks
$modules = ModuleLoader::loadModules();

// Define how many users to display per page
$usersPerPage = 10;

// Fetch all users and total count
$allUsers = $auth->getAllUsers(); // Retrieve all users
$totalUsers = count($allUsers); // Count total users for pagination

// Initialize pagination
$pagination = new Pagination($usersPerPage);
$pagination->setTotalItems($totalUsers);

// Get current page entries for display
$current_page = $pagination->getCurrentPage();
$users = array_slice($allUsers, ($current_page - 1) * $pagination->getLimit(), $pagination->getLimit(), true); // Preserve keys

// Handle the deletion of a user if requested
if (isset($_GET['delete']) && isset($_GET['id'])) {
    $userId = (int) $_GET['id'];
    $auth->deleteById($userId);
    safeRedirect("manage_users.php");
}

// Retrieve any messages to display to the user
$messages = Message::get();

// Include header file for the page layout
include_once __DIR__ . '/header.php';
?>

<div class="content">

    <h1>All Users</h1>

    <!-- Display any messages -->
    <?php if (!empty($messages)): ?>
        <?php foreach ($messages as $msg): ?>
            <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
        <?php endforeach; ?>
    <?php endif; ?>

    <!-- All users -->
    <div class="div-table">
        <div class="div-table-header">
            <div class="header-item">Username</div>
            <div class="header-item">Email</div>
            <div class="header-item">Role</div>
            <div class="header-item">Actions</div>
        </div>

        <div class="div-table-body">
            <?php if (empty($users)): ?>
                <div class="div-table-item">
                    <div class="item-content" colspan="4">No users found.</div>
                </div>
            <?php else: ?>
                <!-- Iterate through each user and display their information -->
                <?php foreach ($users as $userId => $user): ?>
                    <div class="div-table-item">
                        <div class="item-content"><?php echo sanitizeInput($user['username']); ?></div>
                        <div class="item-content"><?php echo sanitizeInput($user['email']); ?></div>
                        <div class="item-content"><?php echo $auth->getRoleName($user['role']); ?></div>
                        <div class="item-content">
                            <!-- Action links for viewing, editing, and deleting users -->
                            <a target="_blank" href="<?= generateBaseUrl(); ?>profile.php?id=<?php echo $userId; ?>"
                                class="action-icon view-icon">
                                <span class="fas fa-eye"></span>
                            </a>
                            <a href="edit_profile.php?id=<?php echo $userId; ?>" class="action-icon edit-icon">
                                <span class="fas fa-edit"></span>
                            </a>
                            <a href="?delete=true&id=<?php echo $userId; ?>" class="action-icon delete-icon"
                                onclick="return confirm('Are you sure you want to delete this user?');">
                                <span class="fas fa-trash-alt"></span>
                            </a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <!-- Render pagination links -->
    <div class="pagination">
        <?php echo $pagination->render('manage_users.php'); ?>
    </div>
</div>

<!-- Include footer file for the page layout -->
<?php include_once __DIR__ . '/footer.php'; ?>