<?php
// Load necessary classes and functions
require_once __DIR__ . '/autoload.php';
require_once __DIR__ . '/functions.php';
require_once __DIR__ . '/config.php';

// Initialize the login class
$auth = new SimpleLogin();

// Redirect to login if the registration is closed
if(!ModuleLoader::getSetting('Default', 'registrationStatus')) {
    safeRedirect('login.php');
}

// Initialize variables using null coalescing operator
$username = $_POST['username'] ?? "";
$email = $_POST['email'] ?? "";

// Process registration if form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userInfo = [
        'username' => trim($_POST['username']),
        'email' => trim($_POST['email']),
        'password' => trim($_POST['password']),
    ];

    // Register the user and store success or error message
    $registrationSuccess = $auth->register($userInfo);
}

// Retrieve any error or success messages
$messages = Message::get();

// Include header file for the page layout
include_once __DIR__ . '/header.php';
?>

<div class="flex-container centered">
    <h1>Register</h1>

    <!-- Display any messages -->
    <?php if (!empty($messages)): ?>
        <?php foreach ($messages as $msg): ?>
            <p class="<?php echo sanitizeInput($msg['type']); ?>"><?php echo sanitizeInput($msg['text']); ?></p>
        <?php endforeach; ?>
    <?php endif; ?>

    <form action="register.php" method="post" class="form login-form">
        <div class="horizontal">
            <div>
                <label for="username">Username:</label>
                <input type="text" name="username" id="username" value="<?php echo sanitizeInput($username); ?>"
                    required class="size-small">
            </div>

            <div>
                <label for="email">Email:</label>
                <input type="email" name="email" id="email" value="<?php echo sanitizeInput($email); ?>" required
                    class="size-small">
            </div>
        </div>

        <div class="horizontal">
            <div>
                <label for="password">Password:</label>
                <input type="password" name="password" id="password" required class="size-small">
            </div>

            <div>
                <label for="confirm_password">Confirm Password:</label>
                <input type="password" name="confirm_password" id="confirm_password" required class="size-small">
            </div>
        </div>
        
        <button type="submit" class="large">Register</button>
    </form>

    <!-- Login link -->
    <p>Already have an account? <a href="login.php">Login here</a>.</p>

</div>

<!-- Include footer file for the page layout -->
<?php include_once __DIR__ . '/footer.php'; ?>